Pattern Parent Class
========================

Every pattern described herin inherits from the
parent `Pattern` class and implements its methods.

.. autoclass:: paragami.base_patterns.Pattern
   :members:
